package
Version:
v0.0.0-...-c40c2f6
Opens a new window with list of versions in this module.
Published: Jan 18, 2026
License: Unlicense
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func DisplayUnifiedDiff(before, after, filename string) bool
DisplayUnifiedDiff displays a unified diff with color highlighting
Returns true if there were changes, false otherwise
Source Files
¶
Click to show internal directories.
Click to hide internal directories.