git

package
v0.0.0-...-c40c2f6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 18, 2026 License: Unlicense Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type CommitInfo

type CommitInfo struct {
	Hash           string
	Author         string
	AuthorEmail    string
	Committer      string
	CommitterEmail string
	Date           time.Time
	Message        string
	ParentHashes   []string
	Files          []FileInfo
}

func WalkRepository

func WalkRepository(repoPath string, progressCallback func(int)) ([]CommitInfo, error)

WalkRepository walks through all commits in a git repository The progressCallback is called periodically with the number of commits found so far

type FileInfo

type FileInfo struct {
	Path       string
	Size       int64
	Mode       string
	Content    []byte
	SHA256Hash string
}

type RefInfo

type RefInfo struct {
	Type       string // "branch" or "tag"
	Name       string
	TargetHash string
}

type RemoteInfo

type RemoteInfo struct {
	Name string
	URL  string
}

type RepoMetadata

type RepoMetadata struct {
	Refs    []RefInfo
	Remotes []RemoteInfo
}

func GetRepoMetadata

func GetRepoMetadata(repoPath string) (*RepoMetadata, error)

GetRepoMetadata retrieves repository metadata (branches, tags, remotes)

Jump to