Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CommitInfo ¶
type CommitInfo struct {
Hash string
Author string
AuthorEmail string
Committer string
CommitterEmail string
Date time.Time
Message string
ParentHashes []string
Files []FileInfo
}
func WalkRepository ¶
func WalkRepository(repoPath string, progressCallback func(int)) ([]CommitInfo, error)
WalkRepository walks through all commits in a git repository The progressCallback is called periodically with the number of commits found so far
type RemoteInfo ¶
type RepoMetadata ¶
type RepoMetadata struct {
Refs []RefInfo
Remotes []RemoteInfo
}
func GetRepoMetadata ¶
func GetRepoMetadata(repoPath string) (*RepoMetadata, error)
GetRepoMetadata retrieves repository metadata (branches, tags, remotes)
Click to show internal directories.
Click to hide internal directories.