Documentation
¶
Index ¶
- func ComputeBlocked(g *relations.RelationsGraph, tasks map[string]*types.Task, blockingAxis string, ...)
- func GenerateTaskUUID() (string, error)
- func GetCurrentUser() (string, error)
- func GetTransitiveBlockers(g *relations.RelationsGraph, taskUUID string, tasks map[string]*types.Task, ...) []types.Blocker
- func SplitEventID(eventID string) []string
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ComputeBlocked ¶
func ComputeBlocked(g *relations.RelationsGraph, tasks map[string]*types.Task, blockingAxis string, doneStates []string)
ComputeBlocked computes which tasks are blocked based on the blocks relation and the blocking axis configuration
func GenerateTaskUUID ¶
GenerateTaskUUID generates a unique task UUID in the format task-<ulid>
func GetCurrentUser ¶
GetCurrentUser returns the username of the current user It tries multiple methods to determine the username: 1. os/user.Current() (works on most systems) 2. USER environment variable (common on Unix) 3. USERNAME environment variable (common on Windows)
func GetTransitiveBlockers ¶
func GetTransitiveBlockers(g *relations.RelationsGraph, taskUUID string, tasks map[string]*types.Task, blockingAxis string, doneStates []string, maxDepth int) []types.Blocker
GetTransitiveBlockers returns all transitive blockers for a task
func SplitEventID ¶
SplitEventID splits an event ID into its components Format: ev-<number>-<node> or other formats
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.